﻿angular.module('fwapp.controllers')

.controller('OpPrescriptionController', function ($scope, $rootScope, $state, $ionicPlatform, $stateParams, $window, $timeout,
    $ionicPopup, $ionicModal, $ionicLoading, $ionicPopover, $ionicScrollDelegate,
    AccountService, VisitPatientService, RequestService, MedicationPlanService, $fwCordovaToast,$ionicSlideBoxDelegate) {
    // 检查登录状态
    $rootScope.checkLogin();

    // 就诊人ID
    $scope.vpId = $stateParams.vpid;
    // 打哪儿来
    $scope.from = $stateParams.from;
    // 处方列表
    $scope.prescriptionList = [];
    // 是否加载完成
    $scope.isLoadFinish = false;
    // 用药指导
    $scope.instructionList = [];

    // 就诊人列表
    $scope.vpList = [];
    
    // 就诊人信息
    $scope.vpInfo = new Object();

    // 定义滑块
    var slideOpPrescription = $ionicSlideBoxDelegate.$getByHandle('slideOpPrescription');
    // 初始滑块状态
    $scope.step = 0;
    // 门诊处方、出院带药标志位
    $scope.sign = 0;
    // 声明两个数组，可以随意切换用
    $scope.opdList = [];// 门诊处方,门诊 out-patient department
    $scope.lhList = [];// 出院带药，leave hospital

    // 滑到上一步
    $scope.lastSlide = function () {
        slideOpPrescription.previous();
    }
    // 滑到下一步
    $scope.nextSlide = function (index) {
        $scope.sign = index;
        if(index == '1'){
            $scope.prescriptionList = $scope.opdList;
        }
        else if(index == '2'){
            $scope.prescriptionList = $scope.lhList;
        }
        slideOpPrescription.next();
    }
    // 滑到指定页
    $scope.toSlide = function (index) {
        slideOpPrescription.slide(index);
    }

    // 滑块切换触发
    $scope.slideChanged = function () {
        // 记录当前步骤
        $scope.step = slideOpPrescription.currentIndex();
        // 重新计算滚动条高度
        $ionicScrollDelegate.resize();

        // 回到栏目选择页#0 清空列表和内容
        if ($scope.step == 0) {
            $scope.sign = 0;
            $scope.prescriptionList = [];
            $scope.scrollPosition = { left: 0, top: 0, zoom: 1 };
        }
        // 其他页滚到顶
        else {
            $ionicScrollDelegate.scrollTop();
        }
    }

    // 注册弹出菜单：就诊人列表
    $ionicPopover.fromTemplateUrl('pop_vplist.html', {
        scope: $scope
    }).then(function (popover) {
        $scope.popVplist = popover;
    });
    
    // 注册模态窗口：用药指导
    $ionicModal.fromTemplateUrl('instruction.html', {
        scope: $scope
    }).then(function (modal) {
        $scope.instructionModal = modal;
    });

    // 销毁模态窗口
    $scope.$on('$destroy', function () {
        $scope.instructionModal.remove();
    })

    // 读取处方列表
    $scope.getPrescriptionList = function () {
        $scope.isLoadFinish = false;
        $ionicLoading.show();

        // 初始化数组
        $scope.prescriptionList = [];
        $scope.opdList = [];
        $scope.lhList = [];

        $ionicScrollDelegate.scrollTop();
        $ionicScrollDelegate.resize();

        RequestService.getOpPrescription($scope.vpId, localStorage.queryToken).then(function (data) {
            console.log(data);

            if (data.result == 99) {    // 链接超时
                loadFinish();
                $fwCordovaToast.showShortBottom("连接超时，请重试");
                return;
            }
            if (data.result == -2) {
                $ionicLoading.hide();
                $scope.queryPassword().then(function (data) {
                    if (data) {
                        $scope.getPrescriptionList();
                    }
                })
                return;
            }
            if (data.result != 1 && data.result != -1) {  // 请求错误
                loadFinish();
                $fwCordovaToast.showShortBottom(data.msg);
                return;
            }
            if (data.result == -1) {
                $timeout(function () {
                    if (data.is_null != 1) {
                        $scope.prescriptionList = data.data;
                    }
                    loadFinish();
                }, 1500);
                return;
            }
            if (data.is_null != 1) {
                // 分组遍历
                $scope.prescriptionList.length = 0;
                var recipeNumList = new Set(data.data.map(e => e.RECIPE_NUM));
                recipeNumList.forEach(recipeNum => {
                    var group = {};
                    // 处方号
                    group.RECIPE_NUM = recipeNum;
                    // 药品列表
                    group.DRUG_LIST = data.data.filter(e => e.RECIPE_NUM == recipeNum);
                    // 开方日期
                    group.DATE_PRESCRIPTION_FORMAT = new Date(group.DRUG_LIST[0].DATE_PRESCRIPTION).Format("yyyy年MM月dd日");
                    // 处方类型 空/1=门诊处方 2=出院带药
                    group.RECIPT_TYPE = group.DRUG_LIST[0].RECIPT_TYPE;
                    
                    // 推送到对应数组
                    if(group.RECIPT_TYPE == '1'){
                        $scope.opdList.push(group);
                    }
                    else if(group.RECIPT_TYPE == '2'){
                        $scope.lhList.push(group);
                    }

                    // 如果当前在第一页
                    if($scope.step == 1){
                        if($scope.sign == '1'){
                            $scope.prescriptionList = $scope.opdList;
                        }
                        else if($scope.sign == '2'){
                            $scope.prescriptionList = $scope.lhList;
                        }
                    }
                });
            }
            loadFinish();
        });
    }
    
    // 用药指导模态窗口显示
    $scope.instructionShow = function () {
        $scope.instructionModal.show();
        $ionicScrollDelegate.scrollTop();
        $ionicScrollDelegate.resize();
    }

    // 用药指导模态窗口隐藏
    $scope.instructionHide = function () {
        $scope.instructionModal.hide();
        $scope.instructionList = [];
    }

    // 2019-7-26 15:09:19 获取用药指导
    $scope.getInstruction = function (ida) {
        if (ida == null || ida == "") {
            return false;
        }
        $ionicLoading.show();
        MedicationPlanService.getInstruction(ida).then(function (data) {
            console.log(data);
            if (data.result == 1) {
                $scope.instructionList = data.data;
                $scope.instructionShow();
            }
            else if (data.result == 0) {
                $fwCordovaToast.showShortBottom(data.msg);
            }
            $ionicLoading.hide();
        }, function () {
            $ionicLoading.hide();
            $fwCordovaToast.showShortBottom("网络异常，请稍后重试");
        });
    }

    function loadFinish() {
        $ionicLoading.hide();
        $scope.isLoadFinish = true;
    }

    // 切换就诊人
    $scope.changeVp = function (vpid) {
        $scope.vpId = vpid;
        $scope.vpInfo = new Object();
        $scope.loadVPInfo();
        $scope.getPrescriptionList();
        $scope.popVplist.hide();
    }

    // 读取就诊人信息
    $scope.loadVPInfo = function () {
        VisitPatientService.visitPatientInfo($scope.vpId).then(function (data) {
            if (data.result == 0) {
                $fwCordovaToast.showShortBottom(data.msg);
            } else {
                $scope.vpInfo = data.data;
            }
        })
    }

    // 后退
    $scope.goBack = function () {
        if($scope.step == 1){
            $ionicScrollDelegate.scrollTop();
            $scope.lastSlide();
        }
        else{
            if ($scope.from == "app.message") {
                $window.history.back();
            } 
            else if ($stateParams.vpid != null && $stateParams.vpid != "") {
                $state.go('app.visitPatient', { vpid: $stateParams.vpid });
            }
            else {
                $state.go('app.home');
            }
        }
    }

    // 显示弹出菜单
    $scope.openPopoverVpList = function ($event) {
        $scope.popVplist.show($event);
    }

    // 页面进入，绑定后退事件
    $scope.$on('$ionicView.enter', function () {
        if (!$rootScope.checkLogin()) {
            return;
        }

        $ionicPlatform.registerBackButtonAction(function (e) {
            $scope.goBack();
            e.preventDefault();
            return false;
        }, 135, 'opPrescription');
    });

    // 初始化
    $scope.$on('$ionicView.loaded', function () {
        $scope.vpList = [];
        // 获取就诊人列表
        VisitPatientService.visitPatientList().then(function (data) {
            // 获取成功
            if (data.result == 1) {
                // 若无就诊人
                if (data.data.length == 0) {
                    $state.go("app.personal");
                    $fwCordovaToast.showShortBottom("未找到绑定的就诊人信息");
                    return;
                }

                // 第一就诊人
                var vpid = "";
                var vpidSelf = "";
                console.log(data.data.length);
                for (var i = 0; i < data.data.length; i++) {
                    if (data.data[i].IS_BIND_CARD == '1') {
                        $scope.vpList.push(data.data[i]);
                        if (vpid == "") {
                            vpid = data.data[i].VISIT_PATIENT_ID;
                        }
                        if (vpidSelf == "" && data.data[i].IS_SELF == "1") {
                            vpidSelf = data.data[i].VISIT_PATIENT_ID;
                        }
                    }
                }

                // 若参数无就诊人信息
                if ($scope.vpId == "") {
                    // 默认第一就诊人
                    // 2018-9-18 17:33:31 改为本人
                    $scope.vpId = vpidSelf;
                }

                // 若vpid为空
                if (vpid == "") {
                    $state.go("app.personal");
                    $fwCordovaToast.showShortBottom("请绑定就诊卡");
                    $ionicLoading.hide();
                    return;
                } 
                // 无本人就诊人
                else if ($scope.vpId == "") {
                    $fwCordovaToast.showShortBottom("仅允许关系为本人的就诊人查看历史处方");
                    $ionicLoading.hide();
                    return;
                }
                else {
                    $scope.loadVPInfo();
                    $scope.queryPassword().then(function (data) {
                        if (data) {
                            $scope.getPrescriptionList(1);
                        }
                    })
                }
            }
            // 获取失败
            else {
                $fwCordovaToast.showShortBottom(data.msg);
            }
        })
    })

    // 本人数量
    $scope.calcSelf = function () {
        var count = $scope.vpList.filter(e => e.IS_SELF == "1").length;
        return count;
    }

    // 页面退出，解除后退绑定
    $scope.$on('$ionicView.beforeLeave', function () {
        for (actionId in $ionicPlatform.$backButtonActions) {
            if ($ionicPlatform.$backButtonActions[actionId].id == 'opPrescription') {
                $ionicPlatform.$backButtonActions[actionId].priority = 0;
            }
        }
    });

    // dom准备就绪
    ionic.DomUtil.ready(function () {
        // 禁用滑动
        slideOpPrescription.enableSlide(false);
    })
});