﻿angular.module('fwapp.services')

// 在线问诊/复诊诊疗
.service('ConsultationService', function ($q, $http, $timeout, BaseService) {
    return {
        // 检查服务状态
        checkServerStatus: function () {
            return BaseService.post("/Consultation/CheckServerStatus");
        },
        // 获取医师列表
        getDoctorList: function (showAvailable, doctorSearchName, divisionCode, doctorDivisionCode, doctorType, groupCode, groupType) {
            return BaseService.post("/Consultation/GetDoctorList", { showAvailable: showAvailable, doctorSearchName: doctorSearchName, divisionCode: divisionCode, doctorDivisionCode: doctorDivisionCode, doctorType: doctorType, groupCode: groupCode, groupType, groupType });
        },
        // 提交支付申请
        submitApply: function (vpId, treatDoctorId, isConsultation, consultationWay) {
            return BaseService.post("/Consultation/SubmitApply", { vpId: vpId, treatDoctorId: treatDoctorId, isConsultation: isConsultation, consultationWay: consultationWay });
        },
        visitPatientInfo: function (vpId) {
            return BaseService.post("/Consultation/VisitPatientInfo", { vpId: vpId });
        },
        // 获取会话状态
        consultationStatus: function (vpId, doctorCode) {
            return BaseService.post("/Consultation/ConsultationStatus", { vpId: vpId, doctorCode: doctorCode });
        },
        // 获取支付结果
        respApply: function (applyId, infomationId) {
            var deferred = $q.defer();
            // 异步等待通用方法
            function RespApply(applyId, infomationId, count) {
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Consultation/RespApply',
                        data: { applyId: applyId, infomationId: infomationId },
                        withCredentials: true
                    }).success(function (data, status) {
                        if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        else {
                            if (count <= 10) {
                                RespApply(applyId, infomationId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }

            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Consultation/RespApply',
                data: { applyId: applyId, infomationId: infomationId },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == -1) {
                    RespApply(applyId, infomationId, 0);
                }
                else if (data.result == 0) {    // 若返回缓存结果为空 || 报错
                    deferred.resolve(data);
                }
                else if (data.result == 1) {
                    deferred.resolve(data);
                }
                else {
                    RespApply(applyId, infomationId, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 获取配置
        getConfig: function () {
            return BaseService.post("/Consultation/GetConfig");
        },
        // 上传病情描述
        submitInfomation: function (disease, infomation, help, visitHospital, isDrug, drug, isAllergy, allergy, isPreviousDisease, previousDisease, purpose, visitPatientId, doctorCode, infomationId, must, isGuardian, guardianName, guardianPhone, currentAreaCode) {
            return BaseService.post("/Consultation/SubmitInfomation", {
                disease: disease,
                infomation: infomation,
                help: help,
                visitHospital: visitHospital,
                isDrug: isDrug,
                drug: drug,
                isAllergy: isAllergy,
                allergy: allergy,
                isPreviousDisease: isPreviousDisease,
                previousDisease: previousDisease,
                purpose: purpose,
                visitPatientId: visitPatientId,
                doctorCode: doctorCode,
                infomationId: infomationId,
                must: must,
                isGuardian: isGuardian,
                guardianName: guardianName,
                guardianPhone: guardianPhone,
                currentAreaCode: currentAreaCode
            });
        },
        // 获取病情描述列表
        getInfomationList: function (vpId) {
            return BaseService.post("/Consultation/GetInfomationList", { vpId: vpId });
        },
        // 获取病历信息详情
        selectInfomation: function (infomationId) {
            return BaseService.post("/Consultation/SelectInfomation", { infomationId: infomationId });
        },
        // 获取百洋会话状态
        getBYStatus: function (applyId) {
            return BaseService.post("/Consultation/GetBYStatus", { applyId: applyId });
        },
        // 复制图片
        copyImg: function (newId, oldId) {
            return BaseService.post("/Consultation/CopyImg", { newId: newId, oldId: oldId });
        },
        // 回写RECID
        writeBackRecId: function (recId, infomationId) {
            return BaseService.post("/Consultation/WriteBackRecId", { recId: recId, infomationId: infomationId });
        },
        // 查询所患疾病
        searchDisease: function (name, vpId) {
            return BaseService.post("/Consultation/SearchDisease", { name: name, vpId: vpId });
        },
        // 获取上一次诊断
        getDiseaseResp: function (requestId) {
            var deferred = $q.defer();

            // 异步等待通用方法
            function RespGetDisease(requestId, count) {
                var timer = $timeout(function () {
                    $http({
                        method: 'POST',
                        dataType: 'JSON',
                        url: serviceUrl + '/Consultation/GetDiseaseResp',
                        data: { requestId: requestId },
                        withCredentials: true
                    }).success(function (data, status) {
                        if (data.result == 1) {
                            deferred.resolve(data);
                        }
                        else {
                            if (count <= 10) {
                                RespGetDisease(requestId, count + 1);
                            }
                            else {
                                deferred.resolve({ result: 99 });
                            }
                        }
                    })
                }, 1100);
            }

            $http({
                method: 'POST',
                dataType: 'JSON',
                url: serviceUrl + '/Consultation/GetDiseaseResp',
                data: { requestId: requestId },
                withCredentials: true
            }).success(function (data, status) {
                if (data.result == 0) {
                    RespGetDisease(requestId, 0);
                }
                else if (data.result == 1) {
                    deferred.resolve(data);
                }
                else {
                    RespApply(requestId, 0);
                }
            }).error(function (data, status) {
                deferred.reject(data);
            });
            return deferred.promise;
        },
        // 判断是否可以使用复诊续方资质延长
        checkOLCondition: function (vpId){
            return BaseService.post("/Consultation/CheckOLCondition", { vpId: vpId });
        }
    }
})